import { __decorate, __metadata } from "tslib";
import { bindable, containerless } from 'aurelia';
import 'devextreme/dist/css/dx.material.purple.dark.compact.css';
import DataGrid from 'devextreme/ui/data_grid';
let MooDataGrid = class MooDataGrid {
    items = null;
    columns;
    load;
    filterVisible = true;
    headerFilterVisible = false;
    onExportToExcel = false;
    pendingOnly;
    hiddenFilter;
    searchPanelVisible = true;
    onRowUpdating;
    onRowPrepared;
    allowAdding = false;
    allowEditing = false;
    allowDeleting = false;
    allowChoosing = false;
    masterDetail = {};
    extraParams = {};
    searchPanelText;
    storageKey;
    allowColumnResizing;
    allowColumnReordering;
    columnResizingMode;
    confirmDeleteMessage;
    editingMode = 'batch';
    allowedPageSizes = [1, 10, 25, 50, 100];
    popupTitle;
    formItemOptions;
    onOptionChangedFunction;
    onInitNewRowFunction;
    onRowInsertedFunction;
    onRowUpdatedFunction;
    onRowValidating;
    onToolbarPreparing;
    onExporting;
    onCellPrepared;
    dataSource;
    onContentReady;
    //Value for storing filters on new accounts/currency/items filters
    auxFiltersForNewProduct;
    //Values for start and ending dates on toolbars for report.
    startDateForToolbar;
    endDateForToolbar;
    customizeColumns;
    onEditingStart;
    onEditorPreparing;
    closeOnOutsideClick;
    summary;
    control;
    //Array of editable datetime type fields.
    valuesDateTime = ['validThrough'];
    dataGrid;
    dataGridControl;
    attached() {
        this.dataGrid = new DataGrid(this.control, {
            allowColumnReordering: this.allowColumnReordering || true,
            filterRow: {
                visible: this.filterVisible,
                applyFilter: 'auto',
            },
            headerFilter: {
                visible: this.headerFilterVisible,
            },
            searchPanel: {
                visible: this.searchPanelVisible,
                width: 300,
                text: this.searchPanelText,
                searchVisibleColumnsOnly: true,
            },
            loadPanel: {
                width: 100,
            },
            dataSource: this.items || this.dataSource,
            export: {
                enabled: true,
            },
            columnAutoWidth: true,
            rowAlternationEnabled: true,
            remoteOperations: this.items
                ? false
                : {
                    filtering: true,
                    sorting: true,
                    paging: true,
                    grouping: false,
                    summary: false,
                },
            scrolling: {
                mode: 'standard',
                showScrollbar: 'always',
            },
            summary: this.summary ?? {},
            paging: {
                enabled: true,
                pageSize: 25,
            },
            stateStoring: {
                enabled: !this.searchPanelText,
                type: 'sessionStorage',
                storageKey: this.storageKey || 'defaultStorageKey',
            },
            pager: {
                showPageSizeSelector: true,
                allowedPageSizes: this.allowedPageSizes,
            },
            allowColumnResizing: this.allowColumnResizing || true,
            columnResizingMode: this.columnResizingMode || true,
            cellHintEnabled: true,
            showBorders: true,
            showRowLines: false,
            showColumnLines: true,
            columns: this.columns,
            onRowUpdating: this.onRowUpdating,
            onRowPrepared: this.onRowPrepared,
            onRowExpanding: this.onRowExpanding,
            onRowValidating: this.onRowValidating ? (e) => this.onRowValidating(e) : undefined,
            onContentReady: this.onContentReady
                ? this.onContentReady
                : (e) => {
                    // @ts-ignore
                    e.element
                        .querySelector('.dx-datagrid-text-content')
                        .classList.remove('dx-text-content-alignment-left');
                    const countEl = document.getElementById('grid-control-data-count');
                    if (this.items && countEl) {
                        // @ts-ignore
                        countEl.innerText = 'Total Records: ' + this.items.length;
                    }
                    else if (this.dataSource && countEl) {
                        countEl.innerText = 'Total Records: ' + this.dataSource.totalCount();
                    }
                },
            onOptionChanged: this.onOptionChangedFunction
                ? (e) => this.onOptionChangedFunction(e, this.auxFiltersForNewProduct)
                : undefined,
            onInitNewRow: this.onInitNewRowFunction ? (e) => this.onInitNewRowFunction(e) : undefined,
            onRowInserted: this.onRowInsertedFunction
                ? (e) => this.onRowInsertedFunction(e, this.auxFiltersForNewProduct)
                : undefined,
            onRowUpdated: this.onRowUpdatedFunction ? (e) => this.onRowUpdatedFunction(e) : undefined,
            onCellPrepared: this.onCellPrepared ? (e) => this.onCellPrepared(e) : undefined,
            onEditingStart: this.onEditingStart ? (e) => this.onEditingStart(e) : undefined,
            columnChooser: { enabled: this.allowChoosing, mode: 'select' },
            ...this.prepareEditingOptions(),
            masterDetail: {
                enabled: typeof this.masterDetail === 'object' ? false : this.masterDetail,
                template: this.masterDetail,
            },
        });
    }
    /**
     * Prepares the editing options of the Grid based of the binded elements.
     * @returns the editing object for the Grid.
     */
    prepareEditingOptions() {
        return {
            allowUpdating: this.allowEditing,
            allowAdding: this.allowAdding,
            allowDeleting: this.allowDeleting,
            selectTextOnEditStart: true,
            startEditAction: 'click',
            mode: this.editingMode,
            useIcons: true,
            form: {
                colCountByScreen: {
                    xs: 2,
                    sm: 2,
                    md: 3,
                    lg: 4,
                },
                items: this.formItemOptions ? [...this.formItemOptions] : undefined,
            },
            popup: {
                title: this.popupTitle ? this.popupTitle : 'Edit',
                closeOnOutsideClick: !this.closeOnOutsideClick,
                showTitle: true,
            },
            texts: {
                confirmDeleteMessage: this.confirmDeleteMessage ||
                    'Are you sure you want to delete this record? WARNING: This immediately deletes this record.',
            },
        };
    }
    /**
     * Activates a loader and hides the component that trigers
     * @param {Component to hide} data
     * @param {Loader to activate} loaderElement
     */
    startLoader(data, loaderElement) {
        data.component.option('visible', false);
        loaderElement.classList.remove('d-none');
        loaderElement.classList.add('d-block');
    }
    /**
     * deactivates a loader and shows the component that trigers
     * @param {Component to hide} data
     * @param {Loader to activate} loaderElement
     */
    endLoader(data, loaderElement) {
        loaderElement.classList.remove('d-block');
        loaderElement.classList.add('d-none');
        data.component.option('visible', true);
    }
    onRowExpanding = (e) => {
        e.component.collapseAll(-1);
    };
};
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "items", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "columns", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "load", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "filterVisible", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "headerFilterVisible", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "onExportToExcel", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "pendingOnly", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "hiddenFilter", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "searchPanelVisible", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "onRowUpdating", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "onRowPrepared", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "allowAdding", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "allowEditing", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "allowDeleting", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "allowChoosing", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "masterDetail", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "extraParams", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "searchPanelText", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "storageKey", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "allowColumnResizing", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "allowColumnReordering", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "columnResizingMode", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "confirmDeleteMessage", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "editingMode", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "allowedPageSizes", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "popupTitle", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "formItemOptions", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "onOptionChangedFunction", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "onInitNewRowFunction", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "onRowInsertedFunction", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "onRowUpdatedFunction", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "onRowValidating", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "onToolbarPreparing", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "onExporting", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "onCellPrepared", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "dataSource", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "onContentReady", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "auxFiltersForNewProduct", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "startDateForToolbar", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "endDateForToolbar", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "customizeColumns", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "onEditingStart", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "onEditorPreparing", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "closeOnOutsideClick", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "summary", void 0);
__decorate([
    bindable({ mode: 6 /* BindingMode.twoWay */ }),
    __metadata("design:type", Object)
], MooDataGrid.prototype, "control", void 0);
MooDataGrid = __decorate([
    containerless()
], MooDataGrid);
export { MooDataGrid };
//# sourceMappingURL=moo-data-grid.js.map